<?php

class Application_Model_SearchTumblr
{            
    private $client;    
    private $unixtime = "";    
    private $returnXResults = 40;
    private $longSearch = 0;
    private $used_titles = array();
    private $dated_title_version = 0;
    private $goodBlogs = array();
        
    public $blogWordCount = 100;
    public $results = array();
    public $nsfw = false;
    public $count = 1;
    public $usedIds = array();
    public $imagesOnly = false;
    public $customTitlePrefix = "";
    public $negativeKeyword = "";
    public $debug = false;
    public $lazyContent = false;
        
    
    public function __construct($consumerKey, $consumerSecret, $token, $tokenSecret)
    {
        require_once dirname(__FILE__) . '/../tumblr/vendor/autoload.php';
        
        $this->unixtime = time();
        
        $this->client = new Tumblr\API\Client($consumerKey, $consumerSecret, $token, $tokenSecret);
    }
                
    
    /*
     * get tagged posts 
     * @params string keyword, string blog type, boolean long posts returned only
     */
    public function getTaggedPosts( $keyword, $type, $longSearch, $pagingTimeStamp = false )
    {     
        $this->longSearch = $longSearch;
        $day = 1;
        $attempts = 1;
        $skipped = array();        
        
        while (count($this->results) < $this->returnXResults && $attempts < 10)
        {  
            if (!$pagingTimeStamp)
            {
                $multipliedDay = $day * $attempts;
                $this->unixtime = $this->unixtime - ($multipliedDay*24*60*60);
            }
            else
            {
                $this->unixtime = $pagingTimeStamp;
            }
                        
            $blogs = $this->client->getTaggedPosts($keyword, array('before' => $this->unixtime));
            
            foreach ($blogs as $blog)
            {
                
                // if this isn't the type we're looking for, dismiss
                if ($blog->type != $type) { $skipped[] = $blog; continue; }       
                
                // if the blog title is empty generate one, otherwise use blog->title
                $blog->title = $this->generateTitle($blog, $keyword);
                                
                // verify that the content matches the users options                
                if (!$this->verifyContent($blog, $type)) { continue; }
                
                // passed checks, add to used title array
                $this->used_titles[] = $blog->title;                               
                
                // passed all checks, add to return results
                $this->populateResults($blog, $type, $keyword); 
                
                // add the blog to the good blogs array
                $this->goodBlogs[] = $blog;
                
            }
            
            $day++;
            $attempts++;            
        }        
       
        if (count($this->results) < $this->returnXResults && $this->lazyContent)
        {           
            if ($this->debug) { echo "Lazy results\n\n"; }
            $this->checkGoodBlogs();
            $this->lazyPopulateResults($skipped, $keyword, $type);
        }
       
        return $this->results;                
    }
    
    /*
     * populate the return array
     * @params blog object, type
     */
    private function populateResults($blog, $type, $keyword)
    {        
        
            $this->usedIds[] = $blog->id;
            switch($type)
            {
                case "text":                      
                    if ($this->longSearch($blog->body)) 
                    {                           
                        $thumbnail = $this->findThumbnails($blog->body);
                        $body = $blog->body . $this->attribution($blog->blog_name, $blog->post_url);
                        if ($this->checkNegativeKeywords($body)) break;
                        $excerpt = $this->createExcerpt($body, 50);
                        $this->results[] = array(
                            'body' => $body, 
                            'title' => $blog->title, 
                            'date' => $blog->date, 
                            'id' => $blog->id, 
                            'author' => $blog->blog_name, 
                            'post_url' => $blog->post_url,
                            'excerpt' => $excerpt,
                            'thumbnail' => $thumbnail
                        );                    
                    }                    
                    break;
                case "photo":   
                    $photoHtml = "";
                    $thumbnail = false;

                    foreach ($blog->photos as $photo)
                    {                    
                        //$photoHtml .= "<img src='".$photo->alt_sizes->url."' alt='".$keyword."' />";
                        $photoHtml .= "<img src='".$photo->original_size->url."' alt='".$keyword."' />";
                        if (!$thumbnail)
                        {
                            $thumbnail = $photo->original_size->url;
                        }
                    }       

                    $body = $blog->caption . "<br/><br/>" . $photoHtml . $this->attribution($blog->blog_name, $blog->post_url);   
                    if ($this->checkNegativeKeywords($body)) break;
                    $excerpt = $this->createExcerpt($body, 50);
                    
                    $this->results[] = array(
                        'body' => $body, 
                        'title' => $blog->title, 
                        'date' => $blog->date, 
                        'id' => $blog->id, 
                        'author' => $blog->blog_name, 
                        'post_url' => $blog->post_url,
                        'excerpt' => $excerpt,
                        'thumbnail' => $thumbnail
                    );
                case "video":
                    if (!is_array($blog->player)) { break; }
                    $video =  array_pop($blog->player);
                    $body = $video->embed_code . "<br/><br/>" . $blog->caption . $this->attribution($blog->blog_name, $blog->post_url);
                    if ($this->checkNegativeKeywords($body)) break;
                    $excerpt = $this->createExcerpt($body, 50);
                    $this->results[] = array('body' => $body, 
                        'title' => $blog->title, 
                        'date' => $blog->date, 
                        'id' => $blog->id, 
                        'author' => $blog->blog_name, 
                        'post_url' => $blog->post_url,
                        'excerpt' => $excerpt
                    );
                    break;
                case "chat":
                    //$thumbnail = plugin_url('images/chat.jpg', __FILE__);
                    $body = $blog->body . $this->attribution($blog->blog_name, $blog->post_url);
                    $excerpt = $this->createExcerpt($blog->body, 50);
                    if ($this->checkNegativeKeywords($body)) break;
                    $this->results[] = array(
                        'body' => $body, 
                        'title' => $blog->title, 
                        'date' => $blog->date, 
                        'id' => $blog->id, 
                        'author' => $blog->blog_name, 
                        'post_url' => $blog->post_url,
                        'excerpt' => $excerpt,
                        'thumbnail' => false
                    );                 
                    break;
                case "quote":
                    //$thumbnail = plugin_url('images/chat.jpg', __FILE__);
                    $body = $blog->source . $this->attribution($blog->blog_name, $blog->source_url);
                    $excerpt = $this->createExcerpt($blog->body, 50);
                    if ($this->checkNegativeKeywords($body)) break;
                    $this->results[] = array(
                        'body' => $body, 
                        'title' => $blog->title, 
                        'date' => $blog->date, 
                        'id' => $blog->id, 
                        'author' => $blog->blog_name, 
                        'post_url' => $blog->post_url,
                        'excerpt' => $excerpt,
                        'thumbnail' => false
                    );                 
                    break;
                case "answer":
                    //$thumbnail = plugin_url('images/chat.jpg', __FILE__);
                    $body = "<div class='tsunami_question'>"
                        . $blog->question . "</div>" 
                        . "<div class='tsunami_answer'>" . $blog->answer . "</div>" 
                        . $this->attribution($blog->blog_name, $blog->source_url);
                    $excerpt = $this->createExcerpt($blog->body, 50);
                    if ($this->checkNegativeKeywords($body)) break;
                    $this->results[] = array(
                        'body' => $body, 
                        'title' => $blog->title, 
                        'date' => $blog->date, 
                        'id' => $blog->id, 
                        'author' => $blog->blog_name, 
                        'post_url' => $blog->post_url,
                        'excerpt' => $excerpt,
                        'thumbnail' => false
                    );                 
                    break;
            }
        
        
    }
    
    /*
     * determine whether the post is long enough to return based on longsearch setting
     * @params body text and true or false longsearch
     */
    private function longSearch($body)
    {
        if ($this->longSearch)
        {            
            if (str_word_count($body) > $this->blogWordCount)
            {         
                return true;     
            }
            else
            {
                return false;
            }
        }
        else
        {
            return true;
        }        
    }
    
    private function verifyCleanContent($blog_name)
    {
        // they don't care if its sfw or not, just return true
        if ($this->nsfw)
        {
            return true;
        }
        
        $results = $this->client->getBlogInfo($blog_name . ".tumblr.com");
        
        // return false if they don't want nsfw
        if ($results->blog->is_nsfw)
        {        
            return false;
        }
        else
        {         
            return true;
        }
    }
    
    private function checkId($id)
    {        
        if (in_array($id, $this->usedIds))
        {
            return false;
        }
        else
        {
            return true;
        }
    }
    
    private function imagesOnlyCheck($body)
    {

        if (preg_match("/\<img/", $body))
        {
            return true;               
        }
        else
        {
            return false;
        }
        
        return true;
    }
        
    
    public function syndicatorLink($link, $count, $title)
    {        
        $results = file_get_contents("http://tsunamisites.com/link_syndication/link.php?link=" . urlencode($link) . "&retrieve=" . urlencode($count) ."&title=" . urlencode($title));
        
        return json_decode($results, TRUE);
    }
    
    /*
     * if we didn't find results for the type specified, use other types, so we aren't returning empty results
     * @params array of blog objects
     */
    private function lazyPopulateResults($blogs, $keyword, $type)
    {        
        for ( $x=0; $x < count($blogs); $x++)
        {            
            if (count($this->results) >= $this->returnXResults)
            {                
                return;
            }
            $blogs[$x]->title = $this->generateTitle($blogs[$x], $keyword);
            if ($this->verifyContent($blogs[$x], $type))
            {                
                $this->populateResults($blogs[$x], $blogs[$x]->type, $keyword);
            }            
        }        
    }
    
    /*
     * verify the content against the options the user selected
     * @params blog object
     */
    private function verifyContent($blog, $type)
    {
       
        // verify this isn't a title already in the return results
        if ( in_array($blog->title, $this->used_titles) ) { if ($this->debug) { echo "failed title check with $blog->title \n\n"; } return false; }
        
        // is this ID already used?
        if ( !$this->checkId($blog->id) ) { if ($this->debug) { echo "failed ID check with $blog->id \n\n"; } return false; }

        // check for NSFW
        if ( !$this->verifyCleanContent($blog->blog_name) ) { if ($this->debug) { echo "failed NSFW check \n\n"; } return false; }

        // are we looking for posts with images only?
        if ($type == "text"  && $this->imagesOnly)
        {
            if ( !$this->imagesOnlyCheck($blog->body) ) { if ($this->debug) { echo "failed image check for type $type \n"; } return false; }
        }
                        
        $post_title_exists = post_title_exists($blog->title);
        if ( !empty($post_title_exists) ) { if ($this->debug) { echo "failed existing title check with $blog->title \n\n"; } return false; }

        return true;
    }
   
    private function generateTitle($blog, $keyword)
    {
        // check if the post title already exists
        if (empty($blog->title) || $blog->title == "null")
        {
            $title = $this->customTitlePrefix . " " . ucwords($keyword) . " - " . date("Y-m-d") . " Update #" . $this->duplicate_title_version;
            $this->duplicate_title_version++;
            
            return $title;
        }
        
        return $blog->title;
    }
    
    /*
     * add attribution to the post body
     * @params string author, string originating url
     */
    private function attribution($author, $url)
    {
        $html  = "<div class='tsunami_attribution'>";
        $html .= "<div><b>Author:</b> <a href='$url' target='_blank'>$author</a> </div>";
        //$html .= "<div>$url</a></div>";
        $html .= "</div>";
        
        return $html;
    }        
    
    private function createExcerpt($body, $wordCount)
    {
        $body = strip_tags($body);
        
        $excerpt = implode( 
            '', 
            array_slice( 
                preg_split(
                  '/([\s,\.;\?\!]+)/', 
                  $body, 
                  $wordCount*2+1, 
                  PREG_SPLIT_DELIM_CAPTURE
                ),
                0,
                $wordCount*2-1
            )
        );        
        
        $excerpt = preg_replace("/Author\:.*$/", '', $excerpt);
        
        return $excerpt;
    }
    
    /*
     * get img src locations for thumbnails in posts
     * @params object blog
     */
    private function findThumbnails($blog)
    {        
        preg_match_all( '/src="([^"]*)"/i', $blog, $src);
        
        if (!empty($src[1][0]))
        {
           return $src[1][0];
        }
        else
        {
            return false;
        }                
    }
    
    /*
     * check if the content contains a negative keyword
     * @params string body
     */
    private function checkNegativeKeywords($body)
    {
        
        if (!empty($this->negativeKeyword))
        {
            $negative_keyword_regex = "/" . preg_replace('/,/', '|', $this->negativeKeyword) . "/";
            if (preg_match($negative_keyword_regex, $body))
            {
                if ($this->debug) { echo "Failed negative keyword check in: \n $blog->body \n\n"; } 
                return true;
            }            
        }
        
        return false;
        
    }
    
    /*
     * check the good blogs for additional content
     * @params NONE :)
     */
    private function checkGoodBlogs()
    {
        foreach ($this->goodBlogs as $blog)
        {
            
            $blog_name = $blog->blog_name.".tumblr.com";
            
            $blogs = $this->client->getBlogPosts($blog_name);            
            
            if (!empty($blogs->posts))
            {                
                
            }
            
        }
        
    }
}

