<?php

class tsunami_news_widget extends WP_Widget
{
    public function __construct()
    {
        parent::__construct (
            'tsunami_news_widget',
            __('Tsunami News Widget', 'tsunami_news_widget_domain'),
            array( 'description' => __( 'Display Trending Stories on the Web', ' tsunami_news_widget_domain' ), )
        );
    }
    
    /**
    * Outputs the content of the widget
    *
    * @param array $args
    * @param array $instance
    */
    public function widget( $args, $instance ) 
    {
        $topic = $instance['tsunami_widget_topic'];
        $social = ($instance['tsunami_widget_facebook'] == 1) ? "true" : "false";
        $pictures = ($instance['tsunami_widget_pictures'] == 1) ? "true" : "false";
        $preview = ($instance['tsunami_widget_preview'] == 1) ? "true" : "false";
        $margin = (empty($instance['tsunami_widget_margin'])) ? "margin:10px;" : $instance['tsunami_widget_margin'];
        
        wp_enqueue_script( 'tsunami_news_widget_script', 
                'http://w.newswhip.com/World/' . $topic . '?style=light-theme&count=5&showInteractions='. $social 
                .'&showPreview=' . $preview 
                . '&showImage=' . $pictures, 
                array(), false, true);                
        
        ?>
            <style>.NWFooter {display:none;}/*.newswhip-widget-footer-12212{display:none;}*/.see-all{display:none;}</style>
            <div style='<?php echo $margin; ?>'><div id="newswhip-trending"></div><div class="newswhip-widget-footer-12212"> <p class="right">Powered by <a href="http://www.newswhip.com/NewsWhipWidget">NewsWhip</a></p><a class="widget-logo" href="http://www.newswhip.com/NewsWhipWidget">widget logo</a><div class="cl">&nbsp;</div></div></div>

        <?php 
    }

    /**
     * Outputs the options form on admin
     *
     * @param array $instance The widget options
     */
    public function form( $instance ) 
    {               
        ?>
        <p>
            
            <label for="<?php echo $this->get_field_id( 'tsunami_widget_topic' ); ?>"><?php _e( 'Show Topic:' ); ?></label> 
            <?php echo $this->getTopics($instance); ?>
            <br/><br/>  
            <input id="<?php echo $this->get_field_id( 'tsunami_widget_facebook' ); ?>" type="checkbox" name="<?php echo $this->get_field_name('tsunami_widget_facebook'); ?>" value="1" <?php if ($instance['tsunami_widget_facebook'] == 1): ?> checked <?php endif; ?> /> Show Social Icons?
            <br/><br/>            
            <input id="<?php echo $this->get_field_id( 'tsunami_widget_pictures' ); ?>" type="checkbox" name="<?php echo $this->get_field_name('tsunami_widget_pictures'); ?>" value="1" <?php if ($instance['tsunami_widget_pictures'] == 1): ?> checked <?php endif; ?> /> Show Article Pictures?
            <br/><br/>
            <input id="<?php echo $this->get_field_id( 'tsunami_widget_preview' ); ?>" type="checkbox" name="<?php echo $this->get_field_name('tsunami_widget_preview'); ?>" value="1" <?php if ($instance['tsunami_widget_preview'] == 1): ?> checked <?php endif; ?> /> Show Article Preview?
            <br/><br/>
            Custom Wrapper CSS
            <br/>
            <input id="<?php echo $this->get_field_id( 'tsunami_widget_margin' ); ?>" type="text" name="<?php echo $this->get_field_name('tsunami_widget_margin'); ?>" value="<?php echo $instance['tsunami_widget_margin']; ?>"  /> 
        </p>
        <?php 
    }

    /**
     * Processing widget options on save
     *
     * @param array $new_instance The new options
     * @param array $old_instance The previous options
     */
    public function update( $new_instance, $old_instance ) 
    {
        $instance = array();
        
        $instance['tsunami_widget_facebook'] = ( ! empty( $new_instance['tsunami_widget_facebook'] ) ) ? strip_tags( $new_instance['tsunami_widget_facebook'] ) : '';
        $instance['tsunami_widget_topic'] = ( ! empty( $new_instance['tsunami_widget_topic'] ) ) ? strip_tags( $new_instance['tsunami_widget_topic'] ) : '';
        $instance['tsunami_widget_pictures'] = ( ! empty( $new_instance['tsunami_widget_pictures'] ) ) ? strip_tags( $new_instance['tsunami_widget_pictures'] ) : '';
        $instance['tsunami_widget_preview'] = ( ! empty( $new_instance['tsunami_widget_preview'] ) ) ? strip_tags( $new_instance['tsunami_widget_preview'] ) : '';
        $instance['tsunami_widget_margin'] = ( ! empty( $new_instance['tsunami_widget_margin'] ) ) ? strip_tags( $new_instance['tsunami_widget_margin'] ) : '';
        
        return $instance;
    }
    
    private function getTopics($instance)
    {
        $topics = array('All', 'News', 'Politics', 'Gossip', 'Tech', 'Science', 'Fun', 'Culture', 'Fashion', 'Arts', 'Design', 'Movies', 'Music', 'Gaming', 'Science', 'Environment', 'Psycholoy', 'Life', 'Health', 'Food', 'For Him', 'For Her', 'Opinion', 'Economics', 'Mayhem', 'Left', 'Right', 'Ideas', 'Business', 'The Wire', 'Startups', 'Strategy', 'Media', 'Sports', 'Soccer', 'Rugby', 'Golf', 'Motorsports', 'Cycling', 'Tennis', 'American Football', 'Basketball', 'Cricket', 'Track', 'Baseball', 'Aus Football', 'Ice Hockey');
        
        $html = "<select name='". $this->get_field_name('tsunami_widget_topic') . "' id='". $this->get_field_id( 'tsunami_widget_topic' ) ."'>";
        foreach ($topics as $topic)
        {
            if ($instance['tsunami_widget_topic'] == $topic)
            {
                $html .= "<option value='$topic' selected>$topic</option>";
            }
            else
            {
                $html .= "<option value='$topic'>$topic</option>";
            }            
        }
        $html .= "</select>";
        
        return $html;
    }
}